==> truth-1.0.0-javadoc.jar: reference/lists.js <==
var DATA = [
      { id:0, label:"androidx.test.ext.truth.app", link:"reference/androidx/test/ext/truth/app/package-summary.html", type:"package", deprecated:"false" },
      { id:1, label:"androidx.test.ext.truth.app.NotificationActionSubject", link:"reference/androidx/test/ext/truth/app/NotificationActionSubject.html", type:"class", deprecated:"false" },
      { id:2, label:"androidx.test.ext.truth.app.NotificationSubject", link:"reference/androidx/test/ext/truth/app/NotificationSubject.html", type:"class", deprecated:"false" },
      { id:3, label:"androidx.test.ext.truth.app.PendingIntentSubject", link:"reference/androidx/test/ext/truth/app/PendingIntentSubject.html", type:"class", deprecated:"false" },
      { id:4, label:"androidx.test.ext.truth.content", link:"reference/androidx/test/ext/truth/content/package-summary.html", type:"package", deprecated:"false" },
      { id:5, label:"androidx.test.ext.truth.content.IntentCorrespondences", link:"reference/androidx/test/ext/truth/content/IntentCorrespondences.html", type:"class", deprecated:"false" },
      { id:6, label:"androidx.test.ext.truth.content.IntentSubject", link:"reference/androidx/test/ext/truth/content/IntentSubject.html", type:"class", deprecated:"false" },
      { id:7, label:"androidx.test.ext.truth.os", link:"reference/androidx/test/ext/truth/os/package-summary.html", type:"package", deprecated:"false" },
      { id:8, label:"androidx.test.ext.truth.os.BundleSubject", link:"reference/androidx/test/ext/truth/os/BundleSubject.html", type:"class", deprecated:"false" },
      { id:9, label:"androidx.test.ext.truth.view", link:"reference/androidx/test/ext/truth/view/package-summary.html", type:"package", deprecated:"false" },
      { id:10, label:"androidx.test.ext.truth.view.MotionEventSubject", link:"reference/androidx/test/ext/truth/view/MotionEventSubject.html", type:"class", deprecated:"false" },
      { id:11, label:"androidx.test.ext.truth.view.PointerCoordsSubject", link:"reference/androidx/test/ext/truth/view/PointerCoordsSubject.html", type:"class", deprecated:"false" },
      { id:12, label:"androidx.test.ext.truth.view.PointerPropertiesSubject", link:"reference/androidx/test/ext/truth/view/PointerPropertiesSubject.html", type:"class", deprecated:"false" }

    ];

==> truth-1.2.0-javadoc.jar: reference/lists.js <==
var DATA = [
      { id:0, label:"androidx.test.ext.truth.app", link:"reference/androidx/test/ext/truth/app/package-summary.html", type:"package", deprecated:"false" },
      { id:1, label:"androidx.test.ext.truth.app.NotificationActionSubject", link:"reference/androidx/test/ext/truth/app/NotificationActionSubject.html", type:"class", deprecated:"false" },
      { id:2, label:"androidx.test.ext.truth.app.NotificationSubject", link:"reference/androidx/test/ext/truth/app/NotificationSubject.html", type:"class", deprecated:"false" },
      { id:3, label:"androidx.test.ext.truth.app.PendingIntentSubject", link:"reference/androidx/test/ext/truth/app/PendingIntentSubject.html", type:"class", deprecated:"false" },
      { id:4, label:"androidx.test.ext.truth.content", link:"reference/androidx/test/ext/truth/content/package-summary.html", type:"package", deprecated:"false" },
      { id:5, label:"androidx.test.ext.truth.content.IntentCorrespondences", link:"reference/androidx/test/ext/truth/content/IntentCorrespondences.html", type:"class", deprecated:"false" },
      { id:6, label:"androidx.test.ext.truth.content.IntentSubject", link:"reference/androidx/test/ext/truth/content/IntentSubject.html", type:"class", deprecated:"false" },
      { id:7, label:"androidx.test.ext.truth.os", link:"reference/androidx/test/ext/truth/os/package-summary.html", type:"package", deprecated:"false" },
      { id:8, label:"androidx.test.ext.truth.os.BundleSubject", link:"reference/androidx/test/ext/truth/os/BundleSubject.html", type:"class", deprecated:"false" },
      { id:9, label:"androidx.test.ext.truth.os.ParcelableSubject", link:"reference/androidx/test/ext/truth/os/ParcelableSubject.html", type:"class", deprecated:"false" },
      { id:10, label:"androidx.test.ext.truth.view", link:"reference/androidx/test/ext/truth/view/package-summary.html", type:"package", deprecated:"false" },
      { id:11, label:"androidx.test.ext.truth.view.MotionEventSubject", link:"reference/androidx/test/ext/truth/view/MotionEventSubject.html", type:"class", deprecated:"false" },
      { id:12, label:"androidx.test.ext.truth.view.PointerCoordsSubject", link:"reference/androidx/test/ext/truth/view/PointerCoordsSubject.html", type:"class", deprecated:"false" },
      { id:13, label:"androidx.test.ext.truth.view.PointerPropertiesSubject", link:"reference/androidx/test/ext/truth/view/PointerPropertiesSubject.html", type:"class", deprecated:"false" }

    ];
